@@ -4,11 +4,13 @@ from .flank import Flank
 from .ring import Ring
 from .head import Head
 from .back import Back
+from .inferno import Inferno
 
 __all__ = [
     "Strip",
     "Flank",
     "Ring",
     "Head",
-    "Back"
+    "Back",
+    "Inferno"
 ]
